logjson

package
v0.0.0-...-14d6b26 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Null  = jsontext.Null
	False = jsontext.False
	True  = jsontext.True

	BeginObject = jsontext.BeginObject
	EndObject   = jsontext.EndObject
	BeginArray  = jsontext.BeginArray
	EndArray    = jsontext.EndArray
)
var (
	TokenString = jsontext.String
	TokenInt    = jsontext.Int
	TokenUint   = jsontext.Uint
	TokenFloat  = jsontext.Float
	TokenBool   = jsontext.Bool
)
var File_prototest_proto protoreflect.FileDescriptor
var Marshal = jsonv2.Marshal
var MarshalEncode = jsonv2.MarshalEncode
var NewEncoder = jsontext.NewEncoder

Functions

This section is empty.

Types

type Encoder

type Encoder = jsontext.Encoder

func NewEncoderOf

func NewEncoderOf(w io.Writer) *Encoder

type Kind

type Kind = jsontext.Kind

type Options

type Options = jsontext.Options

func AllowDuplicateNames

func AllowDuplicateNames(v bool) Options

type ProtoTest

type ProtoTest struct {
	Secret string `protobuf:"bytes,1,opt,name=secret,proto3" json:"secret,omitempty"`
	// contains filtered or unexported fields
}

func (*ProtoTest) Descriptor deprecated

func (*ProtoTest) Descriptor() ([]byte, []int)

Deprecated: Use ProtoTest.ProtoReflect.Descriptor instead.

func (*ProtoTest) GetSecret

func (x *ProtoTest) GetSecret() string

func (*ProtoTest) ProtoMessage

func (*ProtoTest) ProtoMessage()

func (*ProtoTest) ProtoReflect

func (x *ProtoTest) ProtoReflect() protoreflect.Message

func (*ProtoTest) Reset

func (x *ProtoTest) Reset()

func (*ProtoTest) String

func (x *ProtoTest) String() string

type Token

type Token = jsontext.Token

type Value

type Value = jsontext.Value

Directories

Path Synopsis
internal
gostd/encoding/json
Package json implements encoding and decoding of JSON as defined in RFC 7159.
Package json implements encoding and decoding of JSON as defined in RFC 7159.
gostd/encoding/json/internal/jsonflags
jsonflags implements all the optional boolean flags.
jsonflags implements all the optional boolean flags.
gostd/encoding/json/internal/jsontest
Package jsontest contains functionality to assist in testing JSON.
Package jsontest contains functionality to assist in testing JSON.
gostd/encoding/json/internal/jsonwire
Package jsonwire implements stateless functionality for handling JSON text.
Package jsonwire implements stateless functionality for handling JSON text.
gostd/encoding/json/jsontext
Package jsontext implements syntactic processing of JSON as specified in RFC 4627, RFC 7159, RFC 7493, RFC 8259, and RFC 8785.
Package jsontext implements syntactic processing of JSON as specified in RFC 4627, RFC 7159, RFC 7493, RFC 8259, and RFC 8785.
gostd/encoding/json/v2
Package json implements semantic processing of JSON as specified in RFC 8259.
Package json implements semantic processing of JSON as specified in RFC 8259.

Jump to