Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Null = jsontext.Null False = jsontext.False True = jsontext.True BeginObject = jsontext.BeginObject EndObject = jsontext.EndObject BeginArray = jsontext.BeginArray EndArray = jsontext.EndArray )
var ( TokenString = jsontext.String TokenInt = jsontext.Int TokenUint = jsontext.Uint TokenFloat = jsontext.Float TokenBool = jsontext.Bool )
var File_prototest_proto protoreflect.FileDescriptor
var Marshal = jsonv2.Marshal
var MarshalEncode = jsonv2.MarshalEncode
var NewEncoder = jsontext.NewEncoder
Functions ¶
This section is empty.
Types ¶
type Encoder ¶
func NewEncoderOf ¶
type Options ¶
func AllowDuplicateNames ¶
type ProtoTest ¶
type ProtoTest struct {
Secret string `protobuf:"bytes,1,opt,name=secret,proto3" json:"secret,omitempty"`
// contains filtered or unexported fields
}
func (*ProtoTest) Descriptor
deprecated
func (*ProtoTest) ProtoMessage ¶
func (*ProtoTest) ProtoMessage()
func (*ProtoTest) ProtoReflect ¶
func (x *ProtoTest) ProtoReflect() protoreflect.Message
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
gostd/encoding/json
Package json implements encoding and decoding of JSON as defined in RFC 7159.
|
Package json implements encoding and decoding of JSON as defined in RFC 7159. |
|
gostd/encoding/json/internal/jsonflags
jsonflags implements all the optional boolean flags.
|
jsonflags implements all the optional boolean flags. |
|
gostd/encoding/json/internal/jsontest
Package jsontest contains functionality to assist in testing JSON.
|
Package jsontest contains functionality to assist in testing JSON. |
|
gostd/encoding/json/internal/jsonwire
Package jsonwire implements stateless functionality for handling JSON text.
|
Package jsonwire implements stateless functionality for handling JSON text. |
|
gostd/encoding/json/jsontext
Package jsontext implements syntactic processing of JSON as specified in RFC 4627, RFC 7159, RFC 7493, RFC 8259, and RFC 8785.
|
Package jsontext implements syntactic processing of JSON as specified in RFC 4627, RFC 7159, RFC 7493, RFC 8259, and RFC 8785. |
|
gostd/encoding/json/v2
Package json implements semantic processing of JSON as specified in RFC 8259.
|
Package json implements semantic processing of JSON as specified in RFC 8259. |
Click to show internal directories.
Click to hide internal directories.